@@ -15,15 +15,14 @@ from sevenbridges.api import Api
 from sevenbridges.config import Config
 
 from sevenbridges.models.invoice import Invoice
-from sevenbridges.models.billing_group import (
-    BillingGroup, BillingGroupBreakdown
-)
+from sevenbridges.models.billing_group import BillingGroup
 from sevenbridges.models.user import User
 from sevenbridges.models.endpoints import Endpoints
 from sevenbridges.models.project import Project
 from sevenbridges.models.task import Task
 from sevenbridges.models.app import App
 from sevenbridges.models.dataset import Dataset
+from sevenbridges.models.drs_import import DRSImportBulk
 from sevenbridges.models.bulk import BulkRecord
 from sevenbridges.models.team import Team, TeamMember
 from sevenbridges.models.member import Member, Permissions
@@ -43,7 +42,7 @@ from sevenbridges.models.enums import (
     AppCopyStrategy, AppRawFormat, AsyncFileOperations, AsyncJobStates,
     AutomationRunActions, DivisionRole, FileStorageType, ImportExportState,
     TaskStatus, TransferState, VolumeAccessMode, VolumeType, PartSize,
-    AutomationStatus,
+    AutomationStatus
 )
 from sevenbridges.errors import (
     SbgError, ResourceNotModified, ReadOnlyPropertyError, ValidationError,
@@ -58,17 +57,16 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 __all__ = [
     # Models
     'Api', 'AsyncJob', 'Automation', 'AutomationRun', 'AutomationMember',
-    'AutomationPackage',  'Config', 'Invoice', 'BillingGroup',
-    'BillingGroupBreakdown', 'User', 'Endpoints', 'Project', 'Task', 'App',
-    'Member', 'Permissions', 'File', 'Export', 'Import', 'Volume',
-    'VolumeObject', 'Marker', 'Division', 'Team', 'TeamMember', 'Dataset',
-    'BulkRecord',
+    'AutomationPackage',  'Config', 'Invoice', 'BillingGroup', 'User',
+    'Endpoints', 'Project', 'Task', 'App', 'Member', 'Permissions', 'File',
+    'Export', 'Import', 'Volume', 'VolumeObject', 'Marker', 'Division', 'Team',
+    'TeamMember', 'Dataset', 'DRSImportBulk', 'BulkRecord',
     # Enums
     'AppCopyStrategy', 'AppRawFormat', 'AppCopyStrategy',
     'AsyncFileOperations', 'AsyncJobStates', 'AutomationRunActions',
-    'DivisionRole', 'FileStorageType', 'ImportExportState', 'TaskStatus',
-    'TransferState', 'VolumeAccessMode', 'VolumeType', 'PartSize',
-    'AutomationStatus',
+    'DivisionRole', 'FileStorageType', 'ImportExportState',
+    'TaskStatus', 'TransferState', 'VolumeAccessMode', 'VolumeType',
+    'PartSize', 'AutomationStatus',
     # Errors
     'SbgError', 'ResourceNotModified', 'ReadOnlyPropertyError',
     'ValidationError', 'TaskValidationError', 'PaginationError', 'BadRequest',
